@@ -16,8 +16,8 @@ class InvalidArgsError(Exception):
 
 _orekit._set_exception_types(JavaError, InvalidArgsError)
 
-VERSION = "9_3"
-CLASSPATH = [os.path.join(__dir__, "orekit-9.2.jar"), os.path.join(__dir__, "hipparchus-core-1.3.jar"), os.path.join(__dir__, "hipparchus-filtering-1.3.jar"), os.path.join(__dir__, "hipparchus-fitting-1.3.jar"), os.path.join(__dir__, "hipparchus-geometry-1.3.jar"), os.path.join(__dir__, "hipparchus-ode-1.3.jar"), os.path.join(__dir__, "hipparchus-optim-1.3.jar"), os.path.join(__dir__, "hipparchus-stat-1.3.jar")]
+VERSION = "10.1"
+CLASSPATH = [os.path.join(__dir__, "orekit-10.1.jar"), os.path.join(__dir__, "hipparchus-core-1.6.jar"), os.path.join(__dir__, "hipparchus-filtering-1.6.jar"), os.path.join(__dir__, "hipparchus-fitting-1.6.jar"), os.path.join(__dir__, "hipparchus-geometry-1.6.jar"), os.path.join(__dir__, "hipparchus-ode-1.6.jar"), os.path.join(__dir__, "hipparchus-optim-1.6.jar"), os.path.join(__dir__, "hipparchus-stat-1.6.jar"), os.path.join(__dir__, "rugged-2.1.jar")]
 CLASSPATH = os.pathsep.join(CLASSPATH)
 _orekit.CLASSPATH = CLASSPATH
 _orekit._set_function_self(_orekit.initVM, _orekit)
